<?php
/**
 * The plugin bootstrap file
 *
 * This file is read by WordPress to generate the plugin information in the plugin
 * admin area. This file also includes all of the dependencies used by the plugin,
 * registers the activation and deactivation functions, and defines a function
 * that starts the plugin.
  *
 * @link              https://americanimmigrationcouncil.org/content/immigration-impact-rss-feed-display-wordpress-plugin
 * @since             1.0.0
 * @package           immigrationimpact-rss-feeds
 *
 * @wordpress-plugin
 * Plugin Name:       Immigration Impact RSS Feed Display
 * Plugin URI:        https://americanimmigrationcouncil.org/content/immigration-impact-rss-feed-display-wordpress-plugin
 * Description:       A small plugin that allows you to easily display the most recent immigrationimpact.org blog posts anywhere on your site with a widget or shortcode.
 * Version:           1.0.0
 * Author:            American Immigration Council
 * Author URI:        https://americanimmigrationcouncil.org
 * License:           GPL-2.0+
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain:       immigrationimpact-rss-feeds
 * WordPress Available:  yes
 * Requires License:    no
 */
// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}
/**
 * The code that runs during plugin activation.
 * This action is documented in includes/feedzy-rss-feeds-activator.php
 */
function activate_immimpact_rss_feeds() {
	Feedzy_Rss_Feeds_Activator::activate();
}

/**
 * The code that runs during plugin deactivation.
 * This action is documented in includes/feedzy-rss-feeds-deactivator.php
 *
 * @since    3.0.0
 */
function deactivate_immimpact_rss_feeds() {
	Feedzy_Rss_Feeds_Deactivator::deactivate();
}

register_activation_hook( __FILE__, 'activate_immimpact_rss_feeds' );
register_deactivation_hook( __FILE__, 'deactivate_immimpact_rss_feeds' );
/**
 * The function that will handle the queue for autoloader.
 *
 * @since    3.0.0
 */
function immimpact_rss_feeds_autoload( $class ) {
	$namespaces = array( 'Feedzy_Rss_Feeds' );
	foreach ( $namespaces as $namespace ) {
		if ( substr( $class, 0, strlen( $namespace ) ) == $namespace ) {
			$filename = plugin_dir_path( __FILE__ ) . 'includes/' . str_replace( '_', '-', strtolower( $class ) ) . '.php';
			if ( is_readable( $filename ) ) {
				require_once $filename;

				return true;
			}
			$filename = plugin_dir_path( __FILE__ ) . 'includes/abstract/' . str_replace( '_', '-', strtolower( $class ) ) . '.php';
			if ( is_readable( $filename ) ) {
				require_once $filename;

				return true;
			}
			$filename = plugin_dir_path( __FILE__ ) . 'includes/admin/' . str_replace( '_', '-', strtolower( $class ) ) . '.php';
			if ( is_readable( $filename ) ) {
				require_once $filename;

				return true;
			}
		}
	}
	if ( is_readable( plugin_dir_path( __FILE__ ) . 'includes/admin/feedzy-wp-widget.php' ) ) {
		require_once plugin_dir_path( __FILE__ ) . 'includes/admin/feedzy-wp-widget.php';

		return true;
	}

	return false;
}

/**
 * Begins execution of the plugin.
 *
 * Since everything within the plugin is registered via hooks,
 * then kicking off the plugin from this point in the file does
 * not affect the page life cycle.
 *
 * @since    3.0.0
 */
function run_immimpact_rss_feeds() {
	define( 'IMMIMPACT_BASEFILE', __FILE__ );
	define( 'IMMIMPACT_ABSURL', plugins_url( '/', __FILE__ ) );
	define( 'IMMIMPACT_ABSPATH', dirname( __FILE__ ) );
	define( 'IMMIMPACT_UPSELL_LINK', '' );
	define( 'IMMIMPACT_NAME', 'Immigration Impact RSS Feeds' );

	// always make this true before testing
	define( 'IMMIMPACT_DISABLE_CACHE_FOR_TESTING', false );
	$immpact = Feedzy_Rss_Feeds::instance();
	$immpact->run();
	$vendor_file = IMMIMPACT_ABSPATH . '/vendor/autoload_52.php';
	if ( is_readable( $vendor_file ) ) {
		require_once $vendor_file;
	}

	

}



spl_autoload_register( 'immimpact_rss_feeds_autoload' );
run_immimpact_rss_feeds();
